@@ -10,7 +10,7 @@ use abscissa_core::{Command, FrameworkError, Runnable};
 use anyhow::Result;
 
 use chrono::Local;
-use merge::Merge;
+use conflate::Merge;
 use serde::{Deserialize, Serialize};
 use serde_with::{serde_as, DisplayFromStr};
 
@@ -70,11 +70,12 @@ pub struct ForgetOptions {
     /// Group snapshots by any combination of host,label,paths,tags (default: "host,label,paths")
     #[clap(long, short = 'g', value_name = "CRITERION")]
     #[serde_as(as = "Option<DisplayFromStr>")]
+    #[merge(strategy=conflate::option::overwrite_none)]
     group_by: Option<SnapshotGroupCriterion>,
 
     /// Also prune the repository
     #[clap(long)]
-    #[merge(strategy = merge::bool::overwrite_false)]
+    #[merge(strategy=conflate::bool::overwrite_false)]
     prune: bool,
 
     /// Snapshot filter options
