@@ -12,10 +12,10 @@ use abscissa_core::config::Config;
 use abscissa_core::path::AbsPathBuf;
 use abscissa_core::FrameworkError;
 use clap::{Parser, ValueHint};
+use conflate::Merge;
 use directories::ProjectDirs;
 use itertools::Itertools;
 use log::Level;
-use merge::Merge;
 use rustic_backend::BackendOptions;
 use rustic_core::RepositoryOptions;
 use serde::{Deserialize, Serialize};
@@ -136,21 +136,22 @@ pub struct GlobalOptions {
         value_name = "PROFILE",
         env = "RUSTIC_USE_PROFILE"
     )]
-    #[merge(strategy = merge::vec::append)]
+    #[merge(strategy=conflate::vec::append)]
     pub use_profiles: Vec<String>,
 
     /// Only show what would be done without modifying anything. Does not affect read-only commands.
     #[clap(long, short = 'n', global = true, env = "RUSTIC_DRY_RUN")]
-    #[merge(strategy = merge::bool::overwrite_false)]
+    #[merge(strategy=conflate::bool::overwrite_false)]
     pub dry_run: bool,
 
     /// Check if index matches pack files and read pack headers if neccessary
     #[clap(long, global = true, env = "RUSTIC_CHECK_INDEX")]
-    #[merge(strategy = merge::bool::overwrite_false)]
+    #[merge(strategy=conflate::bool::overwrite_false)]
     pub check_index: bool,
 
     /// Use this log level [default: info]
     #[clap(long, global = true, env = "RUSTIC_LOG_LEVEL")]
+    #[merge(strategy=conflate::option::overwrite_none)]
     pub log_level: Option<String>,
 
     /// Write log messages to the given file instead of printing them.
@@ -159,6 +160,7 @@ pub struct GlobalOptions {
     ///
     /// Warnings and errors are still additionally printed unless they are ignored by `--log-level`
     #[clap(long, global = true, env = "RUSTIC_LOG_FILE", value_name = "LOGFILE", value_hint = ValueHint::FilePath)]
+    #[merge(strategy=conflate::option::overwrite_none)]
     pub log_file: Option<PathBuf>,
 
     /// Settings to customize progress bars
@@ -168,16 +170,10 @@ pub struct GlobalOptions {
 
     /// List of environment variables to set (only in config file)
     #[clap(skip)]
-    #[merge(strategy = extend)]
+    #[merge(strategy = conflate::hashmap::ignore)]
     pub env: HashMap<String, String>,
 }
 
-/// Extend the contents of a [`HashMap`] with the contents of another
-/// [`HashMap`] with the same key and value types.
-fn extend(left: &mut HashMap<String, String>, right: HashMap<String, String>) {
-    left.extend(right);
-}
-
 /// Get the paths to the config file
 ///
 /// # Arguments
